@@ -1,2 +1,2 @@
 utils::globalVariables(c(".", "report", "lastCalculation", "detailedAccountReports", "name", "X1", "X2", "Term", "segment.marketId", "maturityDate", "cficode", "Cficode", "Symbol", "ProductType", "MarketSegmentId",
-                         "Ticker", "OptionType", "StrikePrice", "Underlying", "Settlement", "MaturityDate", "transactTime", "text", "value"))
+                         "Ticker", "OptionType", "StrikePrice", "Underlying", "Settlement", "MaturityDate", "transactTime", "text", "value", "rRofexWebsockets", "timestamp", "Changes"))
